import 'package:flutter/material.dart';

class LoginForm extends StatefulWidget {
  @override
  _LoginFormState createState() => _LoginFormState();

  final Function(String, String) loginAttempt;
  final String error;

  LoginForm(this.loginAttempt, this.error);
}

class _LoginFormState extends State<LoginForm> {
  bool _busy = false;

  String _username = "";
  String _password = "";

  void _submit() {
    setState(() {
      _busy = true;
    });

    widget.loginAttempt(_username, _password);
  }

  @override
  Widget build(BuildContext context) {
    _busy = false;

    return Column(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        FractionallySizedBox(
          widthFactor: 0.3,
          child: Center(
            child: TextField(
              readOnly: _busy,
              autofocus: true,
              decoration: InputDecoration(
                hintText: "Username",
                border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(5.0),
                  borderSide: BorderSide(
                    color: Colors.blue,
                    style: BorderStyle.solid,
                  ),
                ),
              ),
              onChanged: (content) => _username = content,
              minLines: 1,
              maxLines: 1,
              maxLength: 50,
            ),
          ),
        ),
        FractionallySizedBox(
          widthFactor: 0.3,
          child: TextField(
            readOnly: _busy,
            autofocus: false,
            obscureText: true,
            decoration: InputDecoration(
              hintText: "Password",
              border: OutlineInputBorder(
                borderRadius: BorderRadius.circular(5.0),
                borderSide: BorderSide(
                  color: Colors.blue,
                  style: BorderStyle.solid,
                ),
              ),
            ),
            onChanged: (content) => _password = content,
            minLines: 1,
            maxLines: 1,
            maxLength: 50,
          ),
        ),
        // error message
        if (widget.error != null && widget.error.isNotEmpty)
          Text(
            widget.error,
            style: TextStyle(color: Colors.red),
          ),
        FloatingActionButton(
          onPressed: _submit,
          child: Icon(Icons.login),
          backgroundColor: _busy ? Colors.grey : Colors.blue,
        ),
      ],
    );
  }
}
